#
##  Copyright (c) 1995-2007 University Corporation for Atmospheric Research
## All rights reserved
#
my $pkgdoc = <<'EOD';
#/**----------------------------------------------------------------------
# @file       BJConstants.pm
# Constants for use in routines that process BlackJack type data
#
# @author     Doug Hunt
# @since      10/27/2008
# @version    $URL: svn://ursa.cosmic.ucar.edu/trunk/src/BJutils/BJConstants.pm $ $Id: BJConstants.pm 12073 2009-12-04 18:40:49Z cosmicops $
# cdaacTask   no
# -----------------------------------------------------------------------*/
EOD

package BJConstants;

use Config;

require Exporter;
our @ISA = qw(Exporter);
our @EXPORT = qw(
                 $PI $CLIGHT $F1 $F2 $LAMB1 $LAMB2 $SNRCONV50 $L1_L2 $L2_L1 $RAD2CYC $RAD2DEG $DEG2RAD $BIGENDIAN
                  );

# Conversion factors
$PI        = 4*atan2(1,1);
$CLIGHT    = 299792458;   # speed of light, meters/sec
$F1        = 1575.42e6;   # L1 frequency, Hz
$F2        = 1227.60e6;   # L2 frequency, Hz
$LAMB1     = $CLIGHT/$F1; # L1 wavelength, meters
$LAMB2     = $CLIGHT/$F2; # L2 wavelength, meters
$SNRCONV50 = 50.0 * 4.0 / sqrt(20.456e6 * .75 * .9 * 2.0); # Conversion:  amplitude -> SNR (v/v)
$L1_L2     = $F2/$F1;     # Convert L1 cycles to L2 cycles
$L2_L1     = $F1/$F2;     # Convert L2 cycles to L1 cycles
$RAD2CYC   = 1.0/(2.0*$PI); # Convert radians to cycles
$RAD2DEG   = 180/$PI;
$DEG2RAD   = $PI/180;

my $BIGENDIAN = ($Config{'byteorder'} =~ /4321/);

1;
