my $nprocessors = 24; # number of processors on lynx compute nodes
my $half_processors = int($nprocessors/2);
my $quarter_processors = int($nprocessors/4);

$Config::config = {

  # Satellite configuration info.  Run 'newMissionInfo.pl' to generate /pub/mission/config/brnFil files from this.
  'satellite' => {

                  'pmission'  => 'cnofs', # prototype mission
                  'leoname'   => 'CNFS',  # used in PubFile.pm and elsewhere -- leo number is interpolated into this string
                  'id_num'    => [915],   # Bernese id number (unofficial!!!)
                  'bufr_id'   => [821],   # BUFR file id numbers, assigned by WMO and/or Dave Offiler, UKMET (unofficial!!!--right after SAC-C)
                  'cospar'    => ['2008-017A'], # COSPAR number.  ILRS YYXXXAA -> COSPAR YYYY-XXXA (ex 0702601 -> 2007-026A) MISSION NAME (wikipedia)
                  'mass'      => [383],   # mass in kg of satellite
                  'area'      => [2],     # Square area of velocity direction (m**2) (*very* approximate--guessing cross section of 2m x 1m from photo)
                  'rectype'   => 'CORISS',  # Name of receiver for Bernese tables

                  'antennas'  =>
                    {
                     POD =>

                     # C/NOFS spacecraft coordinate system:
                     #
                     # +Y out of page (pointing to viewer)
                     #
                     #   .-----> +X (velocity)
                     #   |
                     #   |
                     #   V
                     #
                     #   +Z
                     #
                     # The XZ plane is centered on the mounting ring at the 'bottom' of the spacecraft.
                     #
                     # Offsets: (X, Y, Z, mm in SV coordinates)
                     #
                     # Center of mass (COM):  13.04, -662.31, 20.24
                     #
                     # Two points on the CORISS antenna:
                     # -498.07, -905.00, -27.94
                     # -498.07, -915.95, -37.95
                     #
                     # So, lets take the average of these two:  ANT: -498.07, -910.475, -32.945
                     # That means to COM to antenna vector is:  ANT - COM :
                     # (-498.07, -910.475, -32.945) - (13.04, -662.31, 20.24) = [-511.11, -248.165, -53.185] mm
                     #
                     # Bernese spacecraft coordinates:
                     # X, Y, Z (m) +X is (nominal) velocity direction, +Z is (nominal) Earth/nadir direction

                     # So, coordinates must be flipped:    +X(vel)     +X(vel) (both pictures seen from top, towards earth)
                     # 1 0 0      1  0  0                   |           |
                     # 0 1 0  ->  0 -1  0               +Y--o       to  x-- +Y
                     # 0 0 1      0  0 -1

                     # [-511.11, -248.165, -53.185] mm -> [-0.51111, 0.248165, 0.053185] m

                     {'offset'    => [-0.51111, 0.248165, 0.053185],

                      # boresight and azimuth define the North East Up coordinate system used in phase center offsets
                      'boresight' => [ -1,  0, 0], # DX, DY, DZ (m)
                      'azimuth'   => [  0,  0, 1], # X, Y, Z (points in the 'zero' of the azimuth direction)
                                                   # Bernese uses a *left-handed* East, North, Up system:
                                                   # N = azimuth vector
                                                   # U = Boresight
                                                   # E = U x N (remember, left handed)
                                                   # So, 'Up' is normal to the patch, or anti-velocity (-X)
                                                   #     'North' I'm calling +Z or zenith (I have to choose this.  Choice won't matter until
                                                   #        az/el phase center maps are used.
                                                   #     'East' is thus to the right as you stand on top of s/c with head pointing to zenith
                                                   #     (towards the 'nose' of the s/c, away from the attachment ring)

                      # The antenna offsets are currently unknowns, leave as zero
                      'phasectr'  => [0, 0, 0, 0, 0, 0], # L1 (North, East, Up), L2 (North, East, Up) (m)
                      'fullname'  => 'CORISS AFT',
                      'id'        => 0,
                    },

                   },

                  # Used in the BJTools::findAntennaID routine.  Only one antenna, it fulfills all uses
                  'antids' =>
                  {'atmGps' => { SATM_OCC => 0, SATM_REF => 0 },
                   'ionCrx' => { RION_OCC => 0, SION_OCC => 0 },
                   'ionGps' => { RION_OCC => 0, SION_OCC => 0 },
                   'podCrx' => { POD => 0, RION_OCC => 0, SION_OCC => 0 },
                   'podGps' => { POD => 0, RION_OCC => 0, SION_OCC => 0 },
                 },
                },
};

