#
## COSMIC mission:  Post-processing for COSMIC.  Extracted from CDAAC/COSMIC Config.pm on March 31, 2017, SVN version 22847.
#

$Config::config = {

  # Satellite configuration info.
  'satellite' => {

                  'pmission'  => 'cosmic', # prototype mission
                  'leoname'   => 'C%03d',  # used in PubFile.pm and elsewhere -- leo number is interpolated into this string
                  'id_num'    => [921..926], # Bernese id number
                  'bufr_id'   => [740..745], # BUFR file id numbers, assigned by WMO and/or Dave Offiler, UKMET

                  # COSPAR number.  ILRS YYXXXAA -> COSPAR YYYY-XXXA (ex 0702601 -> 2007-026A) MISSION NAME
                  # These are out of A-G order intentionally.  This is the order the 6 COSMIC satellites were injected
                  # into orbit.
                  'cospar'    => ['2006-011B', '2006-011C', '2006-011D', '2006-011E', '2006-011F', '2006-011G'],
                  'mass'      => [61.1, 61.1, 61.0, 61.2, 61.5, 61.5],   # mass in kg of satellite
                  'area'      => [1.00204, 1.00204, 1.0004, 0.99756, 1.00245, 1.00245],  # Square area of velocity direction (m**2)
                  'rectype'   => 'IGOR',   # Name of receiver for Bernese tables

                  'antennas'  =>
                    {
                     POD1 =>
                     # Bernese spacecraft coordinates:
                     # X, Y, Z (m) +X is (nominal) velocity direction, +Z is (nominal) Earth/nadir direction
                     {'offset'    => [[-0.4741, 0.0052, -0.2605],  #fm1
                                      [-0.4735, 0.0046, -0.2603],  #fm2
                                      [-0.4739, 0.0043, -0.2598],
                                      [-0.4746, 0.0045, -0.2597],
                                      [-0.4746, 0.0052, -0.2598],
                                      [-0.4744, 0.0049, -0.2606]], #fm6

                      # boresight and azimuth define the North East Up coordinate system used in phase center offsets
                      # DX, DY, DZ (m)
                      'boresight' => [[-0.9652, 0.0000, -0.2615],  #fm1
                                      [-0.9590, 0.0000, -0.2833],
                                      [-0.9643, 0.0000, -0.2649],
                                      [-0.9659, 0.0000, -0.2588],
                                      [-0.9661, 0.0000, -0.2583],
                                      [-0.9662, 0.0000, -0.2576]], #fm6

                       # X, Y, Z (points in the 'zero' of the azimuth direction)
                      'azimuth'   => [[ 0.2615, 0.0000, -0.9652],  #fm1
                                      [ 0.2833, 0.0000, -0.9590],
                                      [ 0.2649, 0.0000, -0.9643],
                                      [ 0.2588, 0.0000, -0.9659],
                                      [ 0.2583, 0.0000, -0.9661],
                                      [ 0.2576, 0.0000, -0.9662]], #fm6

                      # L1 (North, East, Up), L2 (North, East, Up) (m)
                      'phasectr'  =>  [-0.0345, -0.0016,  0.0598,
                                       -0.0397,  0.0042,  0.0713],
                      'fullname'  => 'HAIGH-FARR (POD1)',
                      'id'        => 0,
                    },

                     POD2 =>
                     # Bernese spacecraft coordinates:
                     # X, Y, Z (m) +X is (nominal) velocity direction, +Z is (nominal) Earth/nadir direction
                     {'offset'    => [[0.4681, 0.0048, -0.2565],
                                      [0.4689, 0.0047, -0.2559],
                                      [0.4682, 0.0047, -0.2547],
                                      [0.4680, 0.0048, -0.2554],
                                      [0.4675, 0.0050, -0.2556],
                                      [0.4678, 0.0042, -0.2557]],

                      # boresight and azimuth define the North East Up coordinate system used in phase center offsets
                      # DX, DY, DZ (m)
                      'boresight' => [[0.9666, 0.0000, -0.2561],
                                      [0.9721, 0.0000, -0.2346],
                                      [0.9669, 0.0000, -0.2553],
                                      [0.9661, 0.0000, -0.2583],
                                      [0.9664, 0.0000, -0.2571],
                                      [0.9669, 0.0000, -0.2553]],

                       # X, Y, Z (points in the 'zero' of the azimuth direction)
                      'azimuth'   => [[-0.2561, 0.0000, -0.9666],
                                      [-0.2346, 0.0000, -0.9721],
                                      [-0.2553, 0.0000, -0.9669],
                                      [-0.2583, 0.0000, -0.9661],
                                      [-0.2571, 0.0000, -0.9664],
                                      [-0.2553, 0.0000, -0.9669]],

                      # L1 (North, East, Up), L2 (North, East, Up) (m)
                      'phasectr'  =>  [-0.0299,  0.0019, 0.0598,
                                       -0.0351, -0.0039, 0.0714],
                      'fullname'  => 'HAIGH-FARR (POD2)',
                      'id'        => 1,
                    },

                     OCC1 =>
                     # Bernese spacecraft coordinates:
                     # X, Y, Z (m) +X is (nominal) velocity direction, +Z is (nominal) Earth/nadir direction
                     {'offset'    => [[-0.4731, 0.0036, 0.2581],
                                      [-0.4742, 0.0032, 0.2581],
                                      [-0.4738, 0.0030, 0.2584],
                                      [-0.4733, 0.0031, 0.2592],
                                      [-0.4736, 0.0031, 0.2589],
                                      [-0.4735, 0.0027, 0.2586]],

                      # boresight and azimuth define the North East Up coordinate system used in phase center offsets
                      # DX, DY, DZ (m)
                      'boresight' => [[-0.8883, 0.0000, 0.4593],
                                      [-0.8905, 0.0000, 0.4551],
                                      [-0.8909, 0.0000, 0.4541],
                                      [-0.8898, 0.0000, 0.4563],
                                      [-0.8903, 0.0000, 0.4554],
                                      [-0.8897, 0.0000, 0.4565]],

                       # X, Y, Z (points in the 'zero' of the azimuth direction)
                      'azimuth'   => [[-0.4593, 0.0000, -0.8883],
                                      [-0.4551, 0.0000, -0.8905],
                                      [-0.4541, 0.0000, -0.8909],
                                      [-0.4563, 0.0000, -0.8898],
                                      [-0.4554, 0.0000, -0.8903],
                                      [-0.4565, 0.0000, -0.8897]],

                      # L1 (North, East, Up), L2 (North, East, Up) (m)
                      'phasectr'  =>  [0.0780, -0.0137,  0.0528,
                                       0.0969, -0.0186,  0.0789],
                      'fullname'  => 'HAIGH-FARR (OCC1)',
                      'id'        => 3, # occ2 = 2, but occ1 = 3 (due to numbering clockwise around satellite)
                    },

                     OCC2 =>
                     # Bernese spacecraft coordinates:
                     # X, Y, Z (m) +X is (nominal) velocity direction, +Z is (nominal) Earth/nadir direction
                     {'offset'    => [[0.4678, -0.0060, 0.2375],
                                      [0.4669, -0.0064, 0.2374],
                                      [0.4673, -0.0060, 0.2380],
                                      [0.4674, -0.0064, 0.2369],
                                      [0.4673, -0.0067, 0.2372],
                                      [0.4672, -0.0059, 0.2380]],

                      # boresight and azimuth define the North East Up coordinate system used in phase center offsets
                      # DX, DY, DZ (m)
                      'boresight' => [[0.8877, 0.0000, 0.4604],
                                      [0.8868, 0.0000, 0.4621],
                                      [0.8885, 0.0000, 0.4588],
                                      [0.8866, 0.0000, 0.4625],
                                      [0.8868, 0.0000, 0.4621],
                                      [0.8855, 0.0000, 0.4647]],

                       # X, Y, Z (points in the 'zero' of the azimuth direction)
                      'azimuth'   => [[0.4604, 0.0000, -0.8877],
                                      [0.4621, 0.0000, -0.8868],
                                      [0.4588, 0.0000, -0.8885],
                                      [0.4625, 0.0000, -0.8866],
                                      [0.4621, 0.0000, -0.8868],
                                      [0.4647, 0.0000, -0.8855]],

                      # L1 (North, East, Up), L2 (North, East, Up) (m)
                      'phasectr'  =>  [0.0742, 0.0142,  0.0526,
                                       0.0931, 0.0191,  0.0787],
                      'fullname'  => 'HAIGH-FARR (OCC2)',
                      'id'        => 2, # occ2 = 2, but occ1 = 3 (due to numbering clockwise around satellite)
                    },
                   },

                  # No 'antids' section is supplied for COSMIC, these values depend upon the
                  # attitude mode (+Xaft or -Xaft) and is computed in BJTools::findAntennaID.
                 },


};
